#!/bin/sh

. /etc/PG.conf

APPNAME="getipmac"
APPCONF="${PGETC}/App/${APPNAME}/app.conf"

ARPOID=".1.3.6.1.2.1.4.22.1.2"
PV6OID=".1.3.6.1.2.1.4.35.1.4"
FLOWEYE="/usr/ramdisk/bin/floweye"
SNMPWALK="/usr/ramdisk/app/${APPNAME}/bin/snmpbulkwalk"

LOGDIR="${DATAPATH}/App/${APPNAME}"
APPSTAT="${LOGDIR}/app.stat"
LOADFILE="${LOGDIR}/load.file"


[ ! -f "${APPCONF}" ] && exit
. ${APPCONF}

lastworktime=$((`date +%s` - 1800))

mkdir -p ${LOGDIR}

while true
do
	sleep 1

	id=0
	cursecs=`date +%s`
	elapse=$((${cursecs} - ${lastworktime}))

	[ ${elapse} -lt ${sleep} ] && continue

	# Mian
	[ -f ${APPSTAT}.bak ] && rm ${APPSTAT}.bak
	[ -f ${LOADFILE} ] && rm ${LOADFILE}

	for line in `echo ${data} | tr "|" " "`
	do
		cur=`date +"%Y-%m-%d %H:%M:%S"`

		_ip=`echo ${line} | cut -d";" -f1`
		_commuty=`echo ${line} | cut -d";" -f2`
		_getipv6=`echo ${line} | cut -d";" -f3`
		
		getfile="${LOGDIR}/get.log"
		stafile="${APPSTAT}.bak"
		
		if [ "${_getipv6}" = "1" ]; then
			_oid=${PV6OID}
		else
			_oid=${ARPOID}
		fi

		${SNMPWALK} -v 2c -Cc -c "${_commuty}" "${_ip}" "${_oid}" | \
		awk -v getfile="${getfile}" -v stafile="${stafile}" -v id=${id} -v getipv6=${_getipv6} \
		'BEGIN {
			getnum = 0;
		}{
			if(getipv6 == 1) {
				# IP-MIB::ipNetToPhysicalPhysAddress.5122.ipv6."fe:80:00:00:00:00:00:00:5a:69:6c:ff:fe:c6:d0:64" = STRING: 58:69:6c:c6:d0:64
				gsub(/"/, "", $1);
				split($1, ip, ".");
				if(ip[3] == "ipv4")
					printf "%s.%s.%s.%s %s\n",
					ip[4], ip[5], ip[6], ip[7], $4 > getfile;
				else
					printf "%s %s\n", ip[4], $4 > getfile;
			} else {
				if($3=="STRING:"){
					split($1 ,arr, ".");
					printf "%s.%s.%s.%s %s\n",
					arr[3], arr[4], arr[5], arr[6], $4 > getfile;
				}
				else if($3=="Hex-STRING:"){
					split($1, arr, ".");
					printf "%s.%s.%s.%s %s:%s:%s:%s:%s:%s\n",
					arr[12], arr[13], arr[14], arr[15], $4, $5, $6, $7, $8, $9 > getfile;
				}
			}
			getnum++;
		} END {
			printf "row_%s=%s\n", id, getnum >> stafile;
		}'

		if [ -f "${getfile}" ]; then
			cat ${getfile} >> ${LOADFILE}
			mv ${getfile} "${LOGDIR}/row_${id}.log"
		fi

		id=$((${id} + 1))
	done

	if [ -f ${LOADFILE} ]; then
		${FLOWEYE} ipmac load file=${LOADFILE}
		rm ${LOADFILE}
	fi

	mv ${APPSTAT}.bak ${APPSTAT}
	sync
	sync
	lastworktime=`date +%s`
done
